BoundInternal

Struct BoundInternal 

pub struct BoundInternal;
Semantically the same as Bound, but reserved for internal usage of the corresponding bus abstraction.

The internal bound context is intended to be used in exactly the same way as the Bound context, with the difference that this DeviceContext is internal to the corresponding bus abstraction.

This context exists for cases where the bus abstraction needs access to internal device infrastructure (such as Device::drvdata_borrow), where CoreInternal would not be justified.