pub trait InternalBoundContext: DeviceContext { }Expand description
Marker trait for DeviceContext types that have internal bound-level access.
This trait is implemented by CoreInternal and BoundInternal, allowing methods that
require internal bus abstraction access to a bound device to be generic over both contexts.
Methods bounded by this trait are available to bus abstractions but not to drivers.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".